COLORS = {
    'black': dict(red=0, green=0, blue=0, alpha=1),
    'grey': dict(red=50, green=50, blue=50, alpha=1),
    'lightgrey': dict(red=50, green=50, blue=50, alpha=.5),
    'red': dict(red=175, green=10, blue=10, alpha=1),
    'lightred': dict(red=175, green=10, blue=10, alpha=.35),
    'blue': dict(red=10, green=25, blue=150, alpha=1),
    'lightblue': dict(red=10, green=25, blue=150, alpha=.35),
    'green': dict(red=20, green=100, blue=50, alpha=1),
    'lightgreen': dict(red=20, green=100, blue=50, alpha=.35),
    'white': dict(red=255, green=255, blue=255, alpha=1)
}
